#!/usr/bin/env python

##dateconfig - Program creates a user interface 
##             that allows the system time, system date,
##             time zone, and ntpd configuration to be easily set
## Copyright (C) 2001 Red Hat, Inc.
## Copyright (C) 2001 Brent Fox <bfox@redhat.com>
##                    Tammy Fox <tfox@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#Originally Written by Brent Fox
#Created May 29, 2001
#Last Modified: May 29, 2001

import os
import time
import string
from gtk import *
from gnome.ui import *
import GtkExtra
from GDK import *
import GdkImlib

comment1 = """
#This file was generated by dateconfig
#
# Undisciplined Local Clock. This is a fake driver intended for backup
# and when no outside source of synchronized time is available. The
# default stratum is usually 3, but in this case we elect to use stratum
# 0. Since the server line does not have the prefer keyword, this driver
# is never used for synchronization, unless no other other
# synchronization source is available. In case the local host is
# controlled by some external source, such as an external oscillator or
# another protocol, the prefer keyword would cause the local host to
# disregard all other synchronization sources, unless the kernel
# modifications are in use and declare an unsynchronized condition.
#

"""

comment2 = """
#
# Drift file.  Put this in a directory which the daemon can write to.
# No symbolic links allowed, either, since the daemon updates the file
# by creating a temporary in the same directory and then rename()'ing
# it to the file.
#
driftfile /etc/ntp/drift
multicastclient                 # listen on default 224.0.1.1
broadcastdelay  0.008

#
# Authentication delay.  If you use, or plan to use someday, the
# authentication facility you should make the programs in the auth_stuff
# directory and figure out what this number should be on your machine.
#
authenticate no

#
# Keys file.  If you want to diddle your server at run time, make a
# keys file (mode 600 for sure) and define the key number to be
# used for making requests.
#
# PLEASE DO NOT USE THE DEFAULT VALUES HERE. Pick your own, or remote
# systems might be able to reset your clock at will. Note also that
# ntpd is started with a -A flag, disabling authentication, that
# will have to be removed as well.
#
#keys           /etc/ntp/keys
"""

class dateBackend:
    def __init__(self):
        pass

    def getDate (self):
        times = time.localtime(time.time())
        return times

    def writeDateConfig (self, sysDate, sysTime):
        year, month, day = sysDate
        hour, min, sec = sysTime

        #--cal.get_date starts counting months at 0 for Jan.  We need to start counting at 1
        month = month + 1
        path = '/bin/date -s %d/%d/%d' % (year,month,day)
        fd = os.popen(path, 'r')
        lines = fd.readlines()
        fd.close()

        path = '/bin/date -s %s:%s:%s' % (hour,min,sec)
        fd = os.popen(path, 'r')
        lines = fd.readlines()
        fd.close()

        # sync hardware clock.  Will use either localtime or utc
        # according to value in /etc/adjtime (recorded last time hwclock
        # was run).
        fd = os.popen("/sbin/hwclock --systohc", 'r')
        lines = fd.readlines()
        fd.close()

    def writeNtpConfig (self, timeServer):
        if os.stat("/etc/ntp.conf"):
            os.rename("/etc/ntp.conf", "/etc/ntp.conf.bak")

        fd = open("/etc/ntp.conf", "w")
        fd.write(comment1)
        fd.write("server %s  \n" % timeServer)
        fd.write("fudge  %s stratum 10 \n" % timeServer)
        fd.write(comment2)
        fd.close()

    def startNtpService (self):
        path = ('/sbin/service ntpd restart')
        os.system (path)
        path = ('/sbin/chkconfig --level 35 ntpd on')
        os.system (path)
        
    def stopNtpService (self):
        path = ('/sbin/service ntpd stop')
        os.system (path)
        path = ('/sbin/chkconfig --level 35 ntpd off')
        os.system (path)
        
    def isNtpRunning (self):
        command = ('/sbin/service ntpd status')
        fd = os.popen(command, 'r')
        output = fd.readlines()
        fd.close()

        line = output[0]

        try:
            if string.index(line, "running") > -1:
                status = TRUE
                return status
        except:
            #Ntp is not running
            pass

        return

    def getNtpServer(self):
        try:
            fd = open('/etc/ntp.conf', 'r')
            lines = fd.readlines()

            for line in lines:
                location = string.find(line, 'server')

                if location == 0:
                    line = string.strip(line)
                    label, server = string.split(line)
                    return server
        except:
            return 

