#!/usr/bin/env python

##dateconfig - Program creates a user interface 
##             that allows the system time, system date,
##             time zone, and ntpd configuration to be easily set
## Copyright (C) 2001 Red Hat, Inc.
## Copyright (C) 2001 Brent Fox <bfox@redhat.com>
##                    Tammy Fox <tfox@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#Originally Written by Brent Fox
#Created May 25, 2001
#Last Modified: May 25, 2001

from gtk import *
from gnome.ui import *
import GtkExtra
from GDK import *
import GdkImlib
import time
import mainWindow
import string

##
## I18N
## 
import gettext
gettext.bindtextdomain ("dateconfig", "/usr/share/locale")
gettext.textdomain ("dateconfig")
_=gettext.gettext

ntp_servers = ["time.nist.gov", "clock.via.net", "timekeeper.isi.edu", "terrapin.csc.ncsu.edu"]

class datePage (GtkVBox):
    def getDate(self):
        return self.cal.get_date()

    def getTime(self):
        if self.flag:
            hour = self.hourEntry.get_text()
            min = self.minEntry.get_text()
            sec = self.secEntry.get_text()
        else:
            hour, min, sec = string.split(self.clock.get(), ":")
        return hour, min, sec

    def getNtpEnabled(self):
        return self.ntp_check_button.get_active()

    def getTimeServer(self):
        return self.ntp_combo.entry.get_text()

    def ntp_check_button_cb(self, args):
        if self.ntp_check_button.get_active() == TRUE:
            self.ntp_combo.set_sensitive(TRUE)
        else:
            self.ntp_combo.set_sensitive(FALSE)
     
    def changed(self, *args):
        self.flag = TRUE

    def __init__(self):
        GtkVBox.__init__(self, FALSE, 5)

        self.flag = FALSE
        times = mainWindow.dateBackend.getDate()

        date_frame = GtkFrame(_("Date"))
        time_frame = GtkFrame(_("Time"))

        hbox = GtkHBox()
        self.pack_start(hbox, FALSE)

        #-----------------Calendar----------#
        self.cal = GtkCalendar()
        self.cal.select_month(times[1]-1, times[0])
        self.cal.select_day(times[2])

        #-----------------Clock-------------#
        self.clock = GtkClock ()
        self.clock.set_format("%H:%M:%S")
        self.clock.set_update_interval(1)
        self.clock.start()

        table = GtkTable(3, 2)
        label = GtkLabel(_("Current Time : "))
        table.attach(label, 0, 1, 0, 1)
        table.attach(self.clock, 1, 2, 0, 1)

        label = GtkLabel(_("Hour : "))
        table.attach(label, 0, 1, 1, 2)
        self.hourEntry = GtkSpinButton()
        self.hourEntry.set_digits(0)
        self.hourEntry.set_editable(FALSE)
        hourAdj = GtkAdjustment(times[3], 0, 24, 1)
        self.hourEntry.set_adjustment(hourAdj)
        self.hourEntry.set_value(times[3])
        table.attach(self.hourEntry, 1, 2, 1, 2)

        label = GtkLabel(_("Minute : "))
        table.attach(label, 0, 1, 2, 3)
        self.minEntry = GtkSpinButton()
        self.minEntry.set_digits(0)
        self.minEntry.set_editable(FALSE)
        minAdj = GtkAdjustment(times[4], 0, 60, 1)
        self.minEntry.set_adjustment(minAdj)
        self.minEntry.set_value(times[4])
        table.attach(self.minEntry, 1, 2, 2, 3)

        label = GtkLabel(_("Second : "))
        table.attach(label, 0, 1, 3, 4)
        self.secEntry = GtkSpinButton()
        self.secEntry.set_digits(0)
        self.secEntry.set_editable(FALSE)
        secAdj = GtkAdjustment(times[5], 0, 60, 1)
        self.secEntry.set_adjustment(secAdj)
        self.secEntry.set_value(times[5])
        table.attach(self.secEntry, 1, 2, 3, 4)

        #----------------Packing details----#
        date_frame.add(self.cal)
        time_frame.add(table)


        #----------------Timeserver frame---#
        timeserver_frame = GtkFrame(_("Network Time Protocol"))
        ts_vbox = GtkVBox(FALSE, 10)
        ts_hbox = GtkHBox(FALSE, 10)
        timeserver_frame.add(ts_vbox)

        label = GtkLabel(_("Your computer can synchronize its clock with "
                         "a remote time server using the Network Time Protocol daemon."))

        label.set_line_wrap(TRUE)

        a = GtkAlignment(0.1, 0.3)
        a.add(label)

        ts_vbox.pack_start(a, FALSE, 10)

        self.ntp_check_button = GtkCheckButton(_("Enable Network Time Protocol"))

        a = GtkAlignment(0.1, 0.3)
        a.add(self.ntp_check_button)

        ts_vbox.pack_start(a, FALSE)

        label = GtkLabel(_("Server:  "))
        self.ntp_combo = GtkCombo()

        self.ntp_combo.set_popdown_strings(ntp_servers)
        self.ntp_combo.set_sensitive(FALSE)
        self.ntp_combo.entry.set_text("")

        self.ntp_check_button.connect("clicked", self.ntp_check_button_cb)

        #Find out if ntpd is currently running.  If so, activate checkbox
        ntpStatus = mainWindow.dateBackend.isNtpRunning()
        if ntpStatus == 1:            
            self.ntp_check_button.set_active(TRUE)
            

        ntpServer = mainWindow.dateBackend.getNtpServer()
        if ntpServer:
            self.ntp_combo.entry.set_text(ntpServer)

        ts_hbox.pack_start(label, FALSE)
        ts_hbox.pack_start(self.ntp_combo, TRUE, TRUE)

        a = GtkAlignment(0.3, 0.5, 0.5, 0)
        a.add(ts_hbox)
        
        ts_vbox.pack_start(a, FALSE)
        
        hbox.pack_start(date_frame, TRUE, 10)
        hbox.pack_start(time_frame, TRUE, 10) 
        self.pack_start(timeserver_frame, TRUE)

        self.hourEntry.connect("changed", self.changed)
        self.minEntry.connect("changed", self.changed)
        self.secEntry.connect("changed", self.changed)
