#!/usr/bin/env python

##dateconfig - Program creates a user interface 
##             that allows the system time, system date,
##             time zone, and ntpd configuration to be easily set
## Copyright (C) 2001 Red Hat, Inc.
## Copyright (C) 2001 Brent Fox <bfox@redhat.com>
##                    Tammy Fox <tfox@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#Originally Written by Brent Fox
#Created January 27, 2001
#Last Modified: May 25, 2001


from gtk import *
from gnome.ui import *
import gnome.help
import GtkExtra
import string
import re
from GDK import *
import GdkImlib
import time
import date_gui
import timezone_gui
import dateBackend
import timezoneBackend

##
## I18N
## 
import gettext
gettext.bindtextdomain ("dateconfig", "/usr/share/locale")
gettext.textdomain ("dateconfig")
_=gettext.gettext

#Initialize date and timezone backend
dateBackend = dateBackend.dateBackend()
timezoneBackend = timezoneBackend.timezoneBackend()
        
class mainWindow:
    def destroy(self, args):
        self.win.destroy()
        mainquit()

    def ok_clicked(self, args):
        self.apply_clicked(args)
        self.destroy(args)

    def apply_clicked(self, args):
        sysDate = self.datePage.getDate()
        sysTime = self.datePage.getTime()
        ntpEnabled = self.datePage.getNtpEnabled()
        sysTimeServer = self.datePage.getTimeServer()
        sysTimezone = self.timezonePage.getTimezone()

        #write time configuration
        self.dateBackend.writeDateConfig(sysDate, sysTime)
        if ntpEnabled == TRUE:
            self.dateBackend.writeNtpConfig(sysTimeServer)
            self.dateBackend.startNtpService()
        else:
            self.dateBackend.stopNtpService()

        self.timezoneBackend.writeConfig(sysTimezone)

    def __init__(self):
        self.dateBackend = dateBackend
        self.timezoneBackend = timezoneBackend

        #--------Create main window and set attributes-------#
        self.win = GtkWindow ()
        self.win.connect ('destroy', self.destroy)
        self.win.set_title (_("Date/Time Properties"))
        self.win.set_default_size (400, 450)
#        self.win.set_usize(400, 450)

        self.win.set_border_width (5)

        vbox = GtkVBox (FALSE, 10)
        self.win.add (vbox)

        #----------------GUI-------------------#
        self.nb = GtkNotebook()

        dateLabel = GtkLabel (_("Date & Time"))
        timezoneLabel = GtkLabel (_("Time Zone"))
        timeserverLabel = GtkLabel (_("Internet Time Servers"))

        vbox.pack_start(self.nb, TRUE)

        self.datePage = date_gui.datePage()
        self.nb.append_page(self.datePage, dateLabel)

        self.timezonePage = timezone_gui.timezonePage()
        self.nb.append_page(self.timezonePage, timezoneLabel)

        #----------------Buttons------------#
        buttonHbox = GtkHButtonBox ()
        vbox.pack_start (buttonHbox, FALSE, 10)
        buttonHbox.set_layout (BUTTONBOX_END)
        buttonHbox.set_spacing(10)

        okButton = GnomePixmapButton  (GnomeStock (STOCK_BUTTON_OK), (_("Ok")))
        buttonHbox.pack_start (okButton)
        okButton.connect ('clicked', self.ok_clicked)

        cancelButton = GnomePixmapButton (GnomeStock (STOCK_BUTTON_CANCEL), (_("Cancel")))
        buttonHbox.pack_start(cancelButton)
        cancelButton.connect('clicked', self.destroy)

        applyButton = GnomePixmapButton (GnomeStock (STOCK_BUTTON_APPLY), (_("Apply")))
        buttonHbox.pack_start (applyButton)
        applyButton.connect ('clicked', self.apply_clicked)

        helpButton = GnomePixmapButton (GnomeStock (STOCK_BUTTON_HELP), (_("Help")))
        buttonHbox.pack_start (helpButton)
        helpButton.connect ('clicked', self.help_clicked)        

        #--------------------------#
        self.win.show_all ()
        mainloop ()

    def help_clicked(self, args):
        help_pages = ["file:///usr/share/doc/dateconfig-0.7.4/time-date.html",
                      "file:///usr/share/doc/dateconfig-0.7.4/time-zone.html"
                      ]
        gnome.help.goto (help_pages [self.nb.get_current_page ()])

