#!/usr/bin/env python

##dateconfig - Program creates a user interface 
##             that allows the system time, system date,
##             time zone, and ntpd configuration to be easily set
## Copyright (C) 2001 Red Hat, Inc.
## Copyright (C) 2001 Brent Fox <bfox@redhat.com>
##                    Tammy Fox <tfox@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#Originally Written by Brent Fox
#Created May 29, 2001
#Last Modified: May 29, 2001

import os
import time
import string

##
## I18N
## 
import gettext
gettext.bindtextdomain ("dateconfig", "/usr/share/locale")
gettext.textdomain ("dateconfig")
_=gettext.gettext

def bool(val):
    if val: return "true"
    return "false"

class timezoneBackend:
    def writeConfig (self, timezoneData):
        self.tz, self.utc, self.arc = timezoneData
        
        instPath = ""
        fromFile = "/usr/share/zoneinfo/" + self.tz

	try:
	    self.copyFile(fromFile, instPath + "/etc/localtime")
	except OSError, (errno, msg):
	    print (_("Error copying timezone (from %s): %s") % (fromFile, msg))


        #Write info to the /etc/sysconfig/clock file
 	f = open(instPath + "/etc/sysconfig/clock", "w")
 	f.write('ZONE="%s"\n' % self.tz)
 	f.write("UTC=%s\n" % self.utc)
 	f.write("ARC=%s\n" % self.arc)
 	f.close()

        f = open(instPath + "/etc/sysconfig/clock", "r")
        tmp = f.read()

    def copyFile(self, source, to):
        f = os.open(source, os.O_RDONLY)
        t = os.open(to, os.O_RDWR | os.O_TRUNC | os.O_CREAT)

        try:
            count = os.read(f, 262144)
            total = 0
            while (count):
                os.write(t, count)

                total = total + len(count)
                count = os.read(f, 16384)
        finally:
            os.close(f)
            os.close(t)

    def getTimezoneInfo (self):
        return (self.tz, self.utc, self.arc)

    def setTimezoneInfo (self, timezone, asUtc = 0, asArc = 0):
        self.tz = timezone
        self.utc = asUtc
        self.arc = asArc

    def __init__(self):
        self.tz = "America/New_York"
        self.utc = 0
        self.arc = 0
        path = '/etc/sysconfig/clock'
        lines = []

        if os.access(path, os.R_OK):
            fd = open(path, 'r')
            lines = fd.readlines()
            fd.close()
        else:
            #There's no /etc/sysconfig/clock file, so make one
            fd = open(path, 'w')
            fd.close
            pass
        
        try:
            for line in lines:
                line = string.strip(line)
                try:
                    tokens = string.split(line, "=")
                    if tokens[0] == "ZONE":
                        self.tz = string.replace(tokens[1], '"', '')
                    if tokens[0] == "UTC":
                        self.utc = tokens[1]
                    if tokens[0] == "ARC":
                        self.arc = tokens[1]
                except:
                    pass
        except:
            pass
